@@ -14,7 +14,7 @@ Version 1.0
 
 =cut
 
-our $VERSION = '1.0.2';
+our $VERSION = '1.0.3';
 
 
 =head1 SYNOPSIS
@@ -383,7 +383,7 @@ sub talk {
     while ( ( $retval, @reply ) = $self->_read_sentence() ) {
         my %dataset;
         foreach my $line ( @reply ) {
-            if ( my ($key, $value) = ( $line =~ /^=(\S+)=(.*)/s ) ) {
+            if ( my ($key, $value) = ( $line =~ /^=([^=]+)=(.*)/s ) ) {
                 $dataset{$key} = $value;
             }
         }
